@@ -1,8 +1,8 @@
-# Base
+# Phases
 from lightwood.analysis.analyze import model_analyzer
 from lightwood.analysis.explain import explain
 
-# Blocks
+# Base blocks
 from lightwood.analysis.base import BaseAnalysisBlock
 from lightwood.analysis.nc.calibrate import ICP
 from lightwood.analysis.helpers.acc_stats import AccStats
@@ -10,11 +10,14 @@ from lightwood.analysis.helpers.conf_stats import ConfStats
 from lightwood.analysis.nn_conf.temp_scale import TempScaler
 from lightwood.analysis.helpers.feature_importance import PermutationFeatureImportance
 
+# Blocks with extra requirements
 try:
     from lightwood.analysis.helpers.shap import ShapleyValues
+    from lightwood.analysis.helpers.pyod import PyOD
 except Exception:
     ShapleyValues = None
+    PyOD = None
 
 
-__all__ = ['model_analyzer', 'explain', 'BaseAnalysisBlock', 'TempScaler',
+__all__ = ['model_analyzer', 'explain', 'BaseAnalysisBlock', 'TempScaler', 'PyOD',
            'ICP', 'AccStats', 'ConfStats', 'PermutationFeatureImportance', 'ShapleyValues']
