@@ -1,12 +1,13 @@
 # TODO: _add_implicit_values unit test ensures NO changes for a fully specified file.
 from copy import deepcopy
 from type_infer.base import TypeInformation
+from dataprep_ml import StatisticalAnalysis
+
 from lightwood.helpers.templating import call, inline_dict, align
 from lightwood.helpers.templating import _consolidate_analysis_blocks
-from lightwood.api import dtype
+from type_infer.dtype import dtype
 from lightwood.api.types import (
     JsonAI,
-    StatisticalAnalysis,
     ProblemDefinition,
 )
 import inspect
@@ -43,12 +44,17 @@ from lightwood.helpers.general import *
 from lightwood.helpers.ts import *
 from lightwood.helpers.log import *
 from lightwood.helpers.numeric import *
-from lightwood.helpers.imputers import *
 from lightwood.helpers.parallelism import *
 from lightwood.helpers.seed import *
 from lightwood.helpers.text import *
 from lightwood.helpers.torch import *
 from lightwood.mixer import *
+
+from dataprep_ml.insights import statistical_analysis
+from dataprep_ml.cleaners import cleaner
+from dataprep_ml.splitters import splitter
+from dataprep_ml.imputers import *
+
 import pandas as pd
 from typing import Dict, List, Union
 import os
@@ -181,7 +187,7 @@ def generate_json_ai(
     problem_definition: ProblemDefinition,
 ) -> JsonAI:
     """
-    Given ``TypeInformation``, ``StatisticalAnalysis``, and the ``ProblemDefinition``, generate a JSON config file with the necessary elements of the ML pipeline populated.
+    Given ``type_infer.TypeInformation``, ``dataprep_ml.StatisticalAnalysis``, and the ``ProblemDefinition``, generate a JSON config file with the necessary elements of the ML pipeline populated.
 
     :param TypeInformation: Specifies what data types each column within the dataset are. Generated by `mindsdb/type_infer`.
     :param statistical_analysis:
@@ -193,12 +199,18 @@ def generate_json_ai(
     exec(IMPORT_EXTERNAL_DIRS, globals())
     target = problem_definition.target
     input_cols = []
+    dependency_dict = {}
     tss = problem_definition.timeseries_settings
+
+    dtype_dict_override = problem_definition.dtype_dict
     dtype_dict = type_information.dtypes
+
     for k in type_information.identifiers:
         if not (tss.is_timeseries and tss.group_by and k in tss.group_by) and k != target:
             del dtype_dict[k]
-    dependency_dict = {}
+
+    for k, v in dtype_dict_override.items():
+        dtype_dict[k] = v
 
     for col_name, col_dtype in dtype_dict.items():
         if (
@@ -393,11 +405,11 @@ def generate_json_ai(
         )
 
     if is_ts:
-        if output_dtype in [dtype.integer, dtype.float]:
+        if output_dtype in [dtype.integer, dtype.float, dtype.quantity]:
             # forces this acc fn for t+1 time series forecasters
             accuracy_functions = ["complementary_smape_array_accuracy"]
 
-        if output_dtype in (dtype.integer, dtype.float, dtype.num_tsarray):
+        if output_dtype in (dtype.integer, dtype.float, dtype.quantity, dtype.num_tsarray):
             imputers.append({"module": "NumericalImputer",
                              "args": {
                                  "value": "'zero'",
@@ -654,14 +666,14 @@ def _add_implicit_values(json_ai: JsonAI) -> JsonAI:
                 "target": "$target",
                 "mode": "$mode",
                 "imputers": "$imputers",
-                "timeseries_settings": "$problem_definition.timeseries_settings",
+                "timeseries_settings": "$problem_definition.timeseries_settings.to_dict()",
                 "anomaly_detection": "$problem_definition.anomaly_detection",
             },
         },
         "splitter": {
             "module": "splitter",
             "args": {
-                "tss": "$problem_definition.timeseries_settings",
+                "tss": "$problem_definition.timeseries_settings.to_dict()",
                 "data": "data",
                 "seed": "$problem_definition.seed_nr",
                 "target": "$target",
@@ -862,10 +874,10 @@ if encoder.is_target:
     # ----------------- #
 
     analyze_data_body = f"""
-self.statistical_analysis = lightwood.data.statistical_analysis(data,
-                                                                self.dtype_dict,
-                                                                {json_ai.identifiers},
-                                                                self.problem_definition)
+self.statistical_analysis = statistical_analysis(data,
+                                                 self.dtype_dict,
+                                                 self.problem_definition.to_dict(),
+                                                 {json_ai.identifiers})
 
 # Instantiate post-training evaluation
 self.analysis_blocks = [{', '.join([call(block) for block in json_ai.analysis_blocks])}]
@@ -1068,23 +1080,25 @@ self.mode = 'train'
 # Prepare data
 # --------------- #
 if dev_data is None:
-    data = train_data if isinstance(train_data, pd.DataFrame) else train_data.data_frame
-    split = splitter(data,
-        self.problem_definition.timeseries_settings,
-        self.dtype_dict,
-        self.problem_definition.seed_nr,
+    data = train_data
+    split = splitter(
+        data=data,
         pct_train=0.8,
         pct_dev=0.2,
         pct_test=0,
-        target=self.target)
+        tss=self.problem_definition.timeseries_settings.to_dict(),
+        seed=self.problem_definition.seed_nr,
+        target=self.target,
+        dtype_dict=self.dtype_dict)
     train_data = split['train']
     dev_data = split['dev']
 
-if isinstance(dev_data, pd.DataFrame):
-    dev_data = EncodedDs(self.encoders, dev_data, self.target)
+if adjust_args is None or not adjust_args.get('learn_call'):
+    train_data = self.preprocess(train_data)
+    dev_data = self.preprocess(dev_data)
 
-if isinstance(train_data, pd.DataFrame):
-    train_data = EncodedDs(self.encoders, train_data, self.target)
+dev_data = EncodedDs(self.encoders, dev_data, self.target)
+train_data = EncodedDs(self.encoders, train_data, self.target)
 
 # --------------- #
 # Update/Adjust Mixers
@@ -1092,7 +1106,7 @@ if isinstance(train_data, pd.DataFrame):
 log.info('Updating the mixers')
 
 for mixer in self.mixers:
-    mixer.partial_fit(train_data, dev_data)
+    mixer.partial_fit(train_data, dev_data, adjust_args)
 """  # noqa
 
     adjust_body = align(adjust_body, 2)
@@ -1142,7 +1156,9 @@ self.analyze_ensemble(enc_train_test)
 if self.problem_definition.fit_on_all:
 
     log.info(f'[Learn phase 8/{n_phases}] - Adjustment on validation requested')
-    self.adjust(enc_train_test["test"], ConcatedEncodedDs([enc_train_test["train"], enc_train_test["dev"]]))
+    self.adjust(enc_train_test["test"].data_frame, ConcatedEncodedDs([enc_train_test["train"],
+                                                                      enc_train_test["dev"]]).data_frame,
+                                                                      adjust_args={'learn_call': True})
 
 """
     learn_body = align(learn_body, 2)
@@ -1266,7 +1282,8 @@ class Predictor(PredictorInterface):
 
     @timed
     def adjust(self, train_data: Union[EncodedDs, ConcatedEncodedDs, pd.DataFrame],
-        dev_data: Optional[Union[EncodedDs, ConcatedEncodedDs, pd.DataFrame]] = None) -> None:
+        dev_data: Optional[Union[EncodedDs, ConcatedEncodedDs, pd.DataFrame]] = None,
+        adjust_args: Optional[dict] = None) -> None:
         # Update mixers with new information
 {adjust_body}
 
